.. _ref-external:

===============
Hangar External
===============

High level interaction interface between hangar and everything external.

High Level Methods
==================
.. automodule:: hangar.external._external
   :members:

Plugin System
=============
.. automodule:: hangar.external.base_plugin
   :members:
